/*
 *	aegis - project change supervisor
 *	Copyright (C) 1999, 2001 Peter Miller;
 *	All rights reserved.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 * MANIFEST: functions to read input from text files
 */

#include <input/crlf.h>
#include <input/file.h>
#include <input/file_text.h>
#include <str.h>


input_ty *
input_file_text_open(fn)
	string_ty	*fn;
{
	return input_crlf(input_file_open(fn), 1);
}


void
input_file_text_escaped_newline(ip)
	input_ty	*ip;
{
	input_crlf_escaped_newline(ip);
}
